%%% Test script for example NEOS-Matlab interface
% 
% 1) Writes XML file to submit AMPL problem to NEOS server
%   - Using test MPEC problems from https://wiki.mcs.anl.gov/leyffer/index.php/MacMPEC
%   - Solving using KNITRO
% 2) Submits problem to NEOS
% 3) Monitors job and collects results
%
% Prior to running, the xmlrpc jars must be downloaded and installed. See 
% instructions in 'config_xmlrpc.m'. 
%
% The location of the NEOS servers must be set in 'config_neos' according to
% http://www.neos-server.org/neos/NEOS-API.html'
%
% Richard Klotz, 2015


%% User Inputs

%%% location of model, data and commands files

%%% for gnash10 problem - Objective should be -230.823
%modelFile = [pwd,filesep,'gnash10',filesep,'gnash1.mod'] ; 
%dataFile = [pwd,filesep,'gnash10',filesep,'gnash10.dat'] ; 
%commandFile = [pwd,filesep,'gnash10',filesep,'gnash1.run'] ;

%%% for taxmcp problem - Objective should be 0.818705
modelFile = [pwd,filesep,'taxmcp',filesep,'taxmcp.mod'] ; 
dataFile = [] ; % no data file
commandFile = [pwd,filesep,'taxmcp',filesep,'taxmcp.run'] ;

%%% comments string
commentsStr = '' ; 

%%% Problem type and solver
categoryStr = 'cp' ;
solverStr = 'KNITRO' ;

%%% Contact E-mail
emailStr = '' ;

%%% Name of XML file to be created
xmlFileName = [pwd,filesep,'neosSubmission.xml'] ;

%%% File to save NEOS job number and password
jobFile = [pwd,filesep,'jobFile'] ;

%%% Name of output file for NEOS results
outputFileName = [pwd,filesep,'resultsFile.txt'] ;

%% Submission
% Create NEOS XML File
xmlStr = neosWriteXML( xmlFileName, modelFile, dataFile, commandFile, categoryStr, solverStr , emailStr, commentsStr ) ;

% Configure XMLRPC and NEOS
% See instructions above
config_xmlrpc() ; % configure xmlrpc
[NEOS_HOST,NEOS_PORT]=config_neos(); % configure neos server settings

%%% host and port loaded in config file
server_url = sprintf('http://%s:%g',NEOS_HOST,NEOS_PORT) ;

% Submit Job
[ job_java ] = neosSubmitJob( xmlStr , server_url, jobFile) ; % submit job

% Monitor Job
pause_secs = 2 ;
neosMonitorJob( job_java, server_url, pause_secs )

% Collect Job
[ results_txt ] = neosCollectJob( job_java, server_url , outputFileName ) ;

% Display Results
display(results_txt)
