function [ job_java ] = neosSubmitJob( xmlString , server_url, jobFilename)
% submitJob - sends file to server using xmlrpc
%             and saves submit information to mat file
%   
%   Inputs:
%   xmlString - XML string to submit to server 
%   server_url -  server address for XML submission
%   jobFilename - filename for storing submission information
%  
%   Outputs:
%   job_java - java object array containing job number and password
%
%   Richard Klotz, 2015

%%% set up xmlrpc client
client = javaObject('org.apache.xmlrpc.client.XmlRpcClient') ;
url = javaObject('java.net.URL', server_url) ;
client.getClientConfig.setServerURL(url);

%%% to get list of methods for neos servers
%methods=client.execute('system.listMethods','');

%%% submit job to neos
disp('Submitting')
job_java = client.execute('submitJob',xmlString) ;

%%% retrieve job number and password
jobNum = job_java(1);
password = job_java(2);
fprintf('Job: %10.0f, PW: %s\n',jobNum,password) ;

%%% save job information
save(jobFilename,'job_java','jobNum','password','server_url','xmlString') ; 

end

