function xmlString=neosWriteXML( xmlFileName, modelFile, dataFile, commandFile, ...
                                 categoryStr, solverStr, emailStr, commentsStr)
% neosWriteXML Write XML string for AMPL job on NEOS optimization servers. 
%              Saves XML file and can return XML string.
%   
%   Inputs:
%   xmlFileName - filename for completed XML file 
%   modelFile - model file
%   dataFile - data file
%   commandFile - commands file
%   commentsFile - filename for comments in NEOS XML file
%   categoryStr - NEOS problem category (lp,nco,cp...)
%   solverStr - NEOS solver name (MOSEK,PATH,KNITRO,Ipopt...)
%   emailStr - email to return NEOS results to
%  
%   Outputs:
%   xmlString - complete xml string
%
%   Other Notes:
%   - modelFile, commandFile and Str inputs are required
%   - dataFile and commentsFile may be left empty ([])
%
%   Richard Klotz, 2015
                             
% load files as strings
if ~isempty(modelFile)
    modelStr = fileread(modelFile);
else
   error('Model file is required.')
end

if ~isempty(dataFile)
    dataStr = fileread(dataFile);
else
    dataStr = '' ;
end

if ~isempty(commandFile)
    commandStr = fileread(commandFile);
else
    error('Command file is required')
end

%%% Print XML string 
xmlString = sprintf( ...
    ['<document> \n' ...
    '<category>%s</category> \n' ...
    '<solver>%s</solver> \n' ...
    '<inputType>AMPL</inputType> \n' ...
    '<client>Mozilla/5.0 (Windows NT 6.3; WOW64; rv:32.0) Gecko/20100101 Firefox/32.0@96.238.136.55</client> \n' ...
    '<priority>long</priority> \n' ...
    '<email>%s</email> \n' ...
    '<model><![CDATA[%s]]></model> \n\n' ...
    '<data><![CDATA[%s]]></data> \n\n' ...
    '<commands><![CDATA[%s]]></commands> \n\n' ...
    '<comments><![CDATA[%s]]></comments> \n\n' ...
    '</document>'] , ...
    categoryStr, solverStr, emailStr, modelStr, dataStr, commandStr, commentsStr ) ;

%%% Save XML string
fid = fopen(xmlFileName, 'w+') ;
fprintf(fid,'%s',xmlString);
fclose(fid);

end

